@@ -4,9 +4,25 @@ def run(target, arg):
 def infos(target, arg):
     target.deploy('infos')
 
+def module(target, arg):
+    mod = target.modules.items.get(arg)
+    if mod:
+        title = f'module {arg}'
+        print(title)
+        print('-'*len(title))
+        print(mod.help())
+    else:
+        print(f' ! unkown module ! {arg}')
+
 def modules(target, arg):
-    for m in sorted(target.modules.items.keys()):
-        print(f'\t{m}')
+    modules = target.modules.items
+    print('modules')
+    print('-------')
+    width = len(max(modules.keys(), key=len))+4
+    for name, mod in sorted(modules.items()):
+        hlp = mod.help()
+        first = hlp.split('\n')[0]
+        print(f'{name:>{width}} {first}')
 
 def deploy(target, arg):
     target.deploy(arg)
