@@ -14,7 +14,7 @@ helps = dict(
     update = '''update packages
     ''',
     upgrade = '''upgrade packages
-    May hang, if user input is required.
+        May hang, if user input is required.
     ''',
     installed = '''list installed packages
     ''',
@@ -44,4 +44,7 @@ helps = dict(
     ''',
     download = '''download file
     ''',
+    logs = '''show log file
+        arg = level (default to "info")
+    ''',
 )
