@@ -5,6 +5,7 @@ readline.parse_and_bind('set editing-mode vi')
 from cmd import Cmd
 
 from setux.main import banner
+from setux.logger import logger
 from .helps import helps
 from . import commands
 
@@ -49,6 +50,10 @@ class Repl(Cmd):
                 first = hlp.split('\n')[0]
                 print(f'{cmd:>{width}} {first}')
 
+    def do_logs(self, level=None):
+        log = logger.logs(level or 'info')
+        print(open(log).read())
+
     def preloop(self):
         print(banner)
         self.onecmd('infos')
